camelot.camelot.model.authentication.RepresentedRepresentor

Package camelot :: Package camelot :: Package model :: Module authentication :: Class RepresentedRepresentor |
[hide private]
[frames] | no frames]

# Class RepresentedRepresentor

source code

Relation from a represented party to the director representing the party

Nested Classes | [hide private]
| Admin

Class Variables | [hide private]
| from_date = `Field(Date(), default= datetime.date.today, requir`...``
| thru_date = `Field(Date(), default= end_of_times, required= Tru`...``
| comment = `Field(Text)`
| established_from = `ManyToOne('Party', required= True, ondelete`...``
| established_to = `ManyToOne('DirectedDirector', required= True,`...``

Class Variable Details | [hide private]

  ### from_date Value:
      Field(Date(), default= datetime.date.today, required= True, index= Tru
      e)

  ### thru_date Value:
      Field(Date(), default= end_of_times, required= True, index= True)

  ### established_from Value:
      ManyToOne('Party', required= True, ondelete= 'cascade', onupdate= 'cas
      cade')

  ### established_to Value:
      ManyToOne('DirectedDirector', required= True, ondelete= 'cascade', onu
      pdate= 'cascade')